@@ -2,10 +2,6 @@
 # Copyright 2013 Julien Danjou
 # Copyright 2014 Red Hat, Inc
 #
-# Authors: Julien Danjou <julien@danjou.info>
-#          Eoghan Glynn <eglynn@redhat.com>
-#          Nejc Saje <nsaje@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -20,21 +16,24 @@
 
 import collections
 import itertools
+import logging
 import random
 
+from concurrent import futures
+from futurist import periodics
 from keystoneauth1 import exceptions as ka_exceptions
-from keystoneclient import exceptions as ks_exceptions
 from oslo_config import cfg
-from oslo_context import context
 from oslo_log import log
 import oslo_messaging
+from oslo_utils import fnmatch
+from oslo_utils import timeutils
 from six import moves
 from six.moves.urllib import parse as urlparse
 from stevedore import extension
 
 from ceilometer.agent import plugin_base
 from ceilometer import coordination
-from ceilometer.i18n import _, _LE, _LI, _LW
+from ceilometer.i18n import _LE, _LI, _LW
 from ceilometer import keystone_client
 from ceilometer import messaging
 from ceilometer import pipeline
@@ -58,6 +57,10 @@ OPTS = [
 ]
 
 POLLING_OPTS = [
+    cfg.StrOpt('cfg_file',
+               default="polling.yaml",
+               help="Configuration file for pipeline definition."
+               ),
     cfg.StrOpt('partitioning_group_prefix',
                deprecated_group='central',
                help='Work-load partitioning group prefix. Use only if you '
@@ -67,17 +70,6 @@ POLLING_OPTS = [
                     'subset of pollsters should be loaded.'),
 ]
 
-cfg.CONF.register_opts(OPTS)
-cfg.CONF.register_opts(POLLING_OPTS, group='polling')
-cfg.CONF.import_opt('telemetry_driver', 'ceilometer.publisher.messaging',
-                    group='publisher_notifier')
-cfg.CONF.import_group('service_types', 'ceilometer.energy.kwapi')
-cfg.CONF.import_group('service_types', 'ceilometer.image.glance')
-cfg.CONF.import_group('service_types', 'ceilometer.neutron_client')
-cfg.CONF.import_group('service_types', 'ceilometer.nova_client')
-cfg.CONF.import_group('service_types', 'ceilometer.objectstore.rgw')
-cfg.CONF.import_group('service_types', 'ceilometer.objectstore.swift')
-
 
 class PollsterListForbidden(Exception):
     def __init__(self):
@@ -88,13 +80,19 @@ class PollsterListForbidden(Exception):
         super(PollsterListForbidden, self).__init__(msg)
 
 
+class EmptyPollstersList(Exception):
+    def __init__(self):
+        msg = ('No valid pollsters can be loaded with the startup parameters'
+               ' polling-namespaces and pollster-list.')
+        super(EmptyPollstersList, self).__init__(msg)
+
+
 class Resources(object):
     def __init__(self, agent_manager):
         self.agent_manager = agent_manager
         self._resources = []
         self._discovery = []
         self.blacklist = []
-        self.last_dup = []
 
     def setup(self, source):
         self._resources = source.resources
@@ -136,8 +134,8 @@ class PollingTask(object):
         resource_factory = lambda: Resources(agent_manager)
         self.resources = collections.defaultdict(resource_factory)
 
-        self._batch = cfg.CONF.batch_polled_samples
-        self._telemetry_secret = cfg.CONF.publisher.telemetry_secret
+        self._batch = self.manager.conf.batch_polled_samples
+        self._telemetry_secret = self.manager.conf.publisher.telemetry_secret
 
     def add(self, pollster, source):
         self.pollster_matches[source.name].add(pollster)
@@ -183,6 +181,7 @@ class PollingTask(object):
                              "%(src)s"),
                          dict(poll=pollster.name, src=source_name))
                 try:
+                    polling_timestamp = timeutils.utcnow().isoformat()
                     samples = pollster.obj.get_samples(
                         manager=self.manager,
                         cache=cache,
@@ -191,6 +190,8 @@ class PollingTask(object):
                     sample_batch = []
 
                     for sample in samples:
+                        # Note(yuywz): Unify the timestamp of polled samples
+                        sample.set_timestamp(polling_timestamp)
                         sample_dict = (
                             publisher_utils.meter_message_from_counter(
                                 sample, self._telemetry_secret
@@ -204,43 +205,45 @@ class PollingTask(object):
                         self._send_notification(sample_batch)
 
                 except plugin_base.PollsterPermanentError as err:
-                    LOG.error(_(
-                        'Prevent pollster %(name)s for '
-                        'polling source %(source)s anymore!')
-                        % ({'name': pollster.name, 'source': source_name}))
+                    LOG.error(_LE(
+                        'Prevent pollster %(name)s from '
+                        'polling %(res_list)s on source %(source)s anymore!')
+                        % ({'name': pollster.name, 'source': source_name,
+                            'res_list': err.fail_res_list}))
                     self.resources[key].blacklist.extend(err.fail_res_list)
                 except Exception as err:
-                    LOG.warning(_(
+                    LOG.error(_LE(
                         'Continue after error from %(name)s: %(error)s')
                         % ({'name': pollster.name, 'error': err}),
                         exc_info=True)
 
     def _send_notification(self, samples):
         self.manager.notifier.sample(
-            self.manager.context.to_dict(),
+            {},
             'telemetry.polling',
             {'samples': samples}
         )
 
 
-class AgentManager(service_base.BaseService):
+class AgentManager(service_base.PipelineBasedService):
+
+    def __init__(self, worker_id, conf, namespaces=None, pollster_list=None, ):
 
-    def __init__(self, namespaces=None, pollster_list=None):
         namespaces = namespaces or ['compute', 'central']
         pollster_list = pollster_list or []
-        group_prefix = cfg.CONF.polling.partitioning_group_prefix
+        group_prefix = conf.polling.partitioning_group_prefix
 
         # features of using coordination and pollster-list are exclusive, and
         # cannot be used at one moment to avoid both samples duplication and
         # samples being lost
-        if pollster_list and cfg.CONF.coordination.backend_url:
+        if pollster_list and conf.coordination.backend_url:
             raise PollsterListForbidden()
 
-        super(AgentManager, self).__init__()
+        super(AgentManager, self).__init__(worker_id, conf)
 
         def _match(pollster):
             """Find out if pollster name matches to one of the list."""
-            return any(utils.match(pollster.name, pattern) for
+            return any(fnmatch.fnmatch(pollster.name, pattern) for
                        pattern in pollster_list)
 
         if type(namespaces) is not list:
@@ -248,7 +251,7 @@ class AgentManager(service_base.BaseService):
 
         # we'll have default ['compute', 'central'] here if no namespaces will
         # be passed
-        extensions = (self._extensions('poll', namespace).extensions
+        extensions = (self._extensions('poll', namespace, self.conf).extensions
                       for namespace in namespaces)
         # get the extensions from pollster builder
         extensions_fb = (self._extensions_from_builder('poll', namespace)
@@ -262,9 +265,21 @@ class AgentManager(service_base.BaseService):
         self.extensions = list(itertools.chain(*list(extensions))) + list(
             itertools.chain(*list(extensions_fb)))
 
-        self.discovery_manager = self._extensions('discover')
-        self.context = context.RequestContext('admin', 'admin', is_admin=True)
-        self.partition_coordinator = coordination.PartitionCoordinator()
+        if self.extensions == []:
+            raise EmptyPollstersList()
+
+        discoveries = (self._extensions('discover', namespace,
+                                        self.conf).extensions
+                       for namespace in namespaces)
+        self.discoveries = list(itertools.chain(*list(discoveries)))
+        self.polling_periodics = None
+
+        self.partition_coordinator = coordination.PartitionCoordinator(
+            self.conf)
+        self.heartbeat_timer = utils.create_periodic(
+            target=self.partition_coordinator.heartbeat,
+            spacing=self.conf.coordination.heartbeat,
+            run_immediately=True)
 
         # Compose coordination group prefix.
         # We'll use namespaces as the basement for this partitioning.
@@ -273,46 +288,52 @@ class AgentManager(service_base.BaseService):
                              if group_prefix else namespace_prefix)
 
         self.notifier = oslo_messaging.Notifier(
-            messaging.get_transport(),
-            driver=cfg.CONF.publisher_notifier.telemetry_driver,
+            messaging.get_transport(self.conf),
+            driver=self.conf.publisher_notifier.telemetry_driver,
             publisher_id="ceilometer.polling")
 
         self._keystone = None
         self._keystone_last_exception = None
 
     @staticmethod
-    def _get_ext_mgr(namespace):
+    def _get_ext_mgr(namespace, *args, **kwargs):
         def _catch_extension_load_error(mgr, ep, exc):
             # Extension raising ExtensionLoadError can be ignored,
             # and ignore anything we can't import as a safety measure.
             if isinstance(exc, plugin_base.ExtensionLoadError):
-                LOG.exception(_("Skip loading extension for %s") % ep.name)
+                LOG.exception(_LE("Skip loading extension for %s"), ep.name)
                 return
+
+            show_exception = (LOG.isEnabledFor(logging.DEBUG)
+                              and isinstance(exc, ImportError))
+            LOG.error(_LE("Failed to import extension for %(name)r: "
+                          "%(error)s"),
+                      {'name': ep.name, 'error': exc},
+                      exc_info=show_exception)
             if isinstance(exc, ImportError):
-                LOG.error(_("Failed to import extension for %(name)s: "
-                            "%(error)s"),
-                          {'name': ep.name, 'error': exc})
                 return
             raise exc
 
         return extension.ExtensionManager(
             namespace=namespace,
             invoke_on_load=True,
+            invoke_args=args,
+            invoke_kwds=kwargs,
             on_load_failure_callback=_catch_extension_load_error,
         )
 
-    def _extensions(self, category, agent_ns=None):
+    def _extensions(self, category, agent_ns=None, *args, **kwargs):
         namespace = ('ceilometer.%s.%s' % (category, agent_ns) if agent_ns
                      else 'ceilometer.%s' % category)
-        return self._get_ext_mgr(namespace)
+        return self._get_ext_mgr(namespace, *args, **kwargs)
 
     def _extensions_from_builder(self, category, agent_ns=None):
         ns = ('ceilometer.builder.%s.%s' % (category, agent_ns) if agent_ns
               else 'ceilometer.builder.%s' % category)
-        mgr = self._get_ext_mgr(ns)
+        mgr = self._get_ext_mgr(ns, self.conf)
 
         def _build(ext):
-            return ext.plugin.get_pollsters_extensions()
+            return ext.plugin.get_pollsters_extensions(self.conf)
 
         # NOTE: this seems a stevedore bug. if no extensions are found,
         # map will raise runtimeError which is not documented.
@@ -323,7 +344,7 @@ class AgentManager(service_base.BaseService):
 
     def join_partitioning_groups(self):
         self.groups = set([self.construct_group_id(d.obj.group_id)
-                          for d in self.discovery_manager])
+                          for d in self.discoveries])
         # let each set of statically-defined resources have its own group
         static_resource_groups = set([
             self.construct_group_id(utils.hash_of_set(p.resources))
@@ -331,6 +352,15 @@ class AgentManager(service_base.BaseService):
             if p.resources
         ])
         self.groups.update(static_resource_groups)
+
+        if not self.groups and self.partition_coordinator.is_active():
+            self.partition_coordinator.stop()
+            self.heartbeat_timer.stop()
+
+        if self.groups and not self.partition_coordinator.is_active():
+            self.partition_coordinator.start()
+            utils.spawn_thread(self.heartbeat_timer.start)
+
         for group in self.groups:
             self.partition_coordinator.join_group(group)
 
@@ -356,42 +386,50 @@ class AgentManager(service_base.BaseService):
                            discovery_group_id)
                 if discovery_group_id else None)
 
-    def configure_polling_tasks(self):
+    def start_polling_tasks(self):
         # allow time for coordination if necessary
         delay_start = self.partition_coordinator.is_active()
 
         # set shuffle time before polling task if necessary
         delay_polling_time = random.randint(
-            0, cfg.CONF.shuffle_time_before_polling_task)
+            0, self.conf.shuffle_time_before_polling_task)
 
-        pollster_timers = []
         data = self.setup_polling_tasks()
+
+        # Don't start useless threads if no task will run
+        if not data:
+            return
+
+        # One thread per polling tasks is enough
+        self.polling_periodics = periodics.PeriodicWorker.create(
+            [], executor_factory=lambda:
+            futures.ThreadPoolExecutor(max_workers=len(data)))
+
         for interval, polling_task in data.items():
             delay_time = (interval + delay_polling_time if delay_start
                           else delay_polling_time)
-            pollster_timers.append(self.tg.add_timer(interval,
-                                   self.interval_task,
-                                   initial_delay=delay_time,
-                                   task=polling_task))
-        self.tg.add_timer(cfg.CONF.coordination.heartbeat,
-                          self.partition_coordinator.heartbeat)
 
-        return pollster_timers
+            @periodics.periodic(spacing=interval, run_immediately=False)
+            def task(running_task):
+                self.interval_task(running_task)
 
-    def start(self):
-        self.polling_manager = pipeline.setup_polling()
+            utils.spawn_thread(utils.delayed, delay_time,
+                               self.polling_periodics.add, task, polling_task)
 
-        self.partition_coordinator.start()
+        utils.spawn_thread(self.polling_periodics.start, allow_empty=True)
+
+    def run(self):
+        super(AgentManager, self).run()
+        self.polling_manager = pipeline.setup_polling(self.conf)
         self.join_partitioning_groups()
-
-        self.pollster_timers = self.configure_polling_tasks()
-
+        self.start_polling_tasks()
         self.init_pipeline_refresh()
 
-    def stop(self):
-        if self.partition_coordinator:
-            self.partition_coordinator.stop()
-        super(AgentManager, self).stop()
+    def terminate(self):
+        self.stop_pollsters_tasks()
+        self.heartbeat_timer.stop()
+        self.partition_coordinator.stop()
+        super(AgentManager, self).terminate()
 
     def interval_task(self, task):
         # NOTE(sileht): remove the previous keystone client
@@ -403,16 +441,25 @@ class AgentManager(service_base.BaseService):
 
     @property
     def keystone(self):
+        # FIXME(sileht): This lazy loading of keystone client doesn't
+        # look concurrently safe, we never see issue because once we have
+        # connected to keystone everything is fine, and because all pollsters
+        # are delayed during startup. But each polling task creates a new
+        # client and overrides it which has been created by other polling
+        # tasks. During this short time bad thing can occur.
+        #
+        # I think we must not reset keystone client before
+        # running a polling task, but refresh it periodically instead.
+
         # NOTE(sileht): we do lazy loading of the keystone client
         # for multiple reasons:
         # * don't use it if no plugin need it
         # * use only one client for all plugins per polling cycle
         if self._keystone is None and self._keystone_last_exception is None:
             try:
-                self._keystone = keystone_client.get_client()
+                self._keystone = keystone_client.get_client(self.conf)
                 self._keystone_last_exception = None
-            except (ka_exceptions.ClientException,
-                    ks_exceptions.ClientException) as e:
+            except ka_exceptions.ClientException as e:
                 self._keystone = None
                 self._keystone_last_exception = e
         if self._keystone is not None:
@@ -426,7 +473,7 @@ class AgentManager(service_base.BaseService):
         return (s.scheme or s.path), (s.netloc + s.path if s.scheme else None)
 
     def _discoverer(self, name):
-        for d in self.discovery_manager:
+        for d in self.discoveries:
             if d.name == name:
                 return d.obj
         return None
@@ -444,7 +491,7 @@ class AgentManager(service_base.BaseService):
                 try:
                     if discoverer.KEYSTONE_REQUIRED_FOR_SERVICE:
                         service_type = getattr(
-                            cfg.CONF.service_types,
+                            self.conf.service_types,
                             discoverer.KEYSTONE_REQUIRED_FOR_SERVICE)
                         if not keystone_client.get_service_catalog(
                                 self.keystone).get_endpoints(
@@ -462,35 +509,32 @@ class AgentManager(service_base.BaseService):
                     resources.extend(partitioned)
                     if discovery_cache is not None:
                         discovery_cache[url] = partitioned
-                except (ka_exceptions.ClientException,
-                        ks_exceptions.ClientException) as e:
+                except ka_exceptions.ClientException as e:
                     LOG.error(_LE('Skipping %(name)s, keystone issue: '
                                   '%(exc)s'), {'name': name, 'exc': e})
                 except Exception as err:
-                    LOG.exception(_('Unable to discover resources: %s') % err)
+                    LOG.exception(_LE('Unable to discover resources: %s'), err)
             else:
-                LOG.warning(_('Unknown discovery extension: %s') % name)
+                LOG.warning(_LW('Unknown discovery extension: %s'), name)
         return resources
 
-    def stop_pollsters(self):
-        for x in self.pollster_timers:
-            try:
-                x.stop()
-                self.tg.timer_done(x)
-            except Exception:
-                LOG.error(_('Error stopping pollster.'), exc_info=True)
-        self.pollster_timers = []
+    def stop_pollsters_tasks(self):
+        if self.polling_periodics:
+            self.polling_periodics.stop()
+            self.polling_periodics.wait()
+        self.polling_periodics = None
 
+    # FIXME(gordc): refactor pipeline dependency out of polling agent.
     def reload_pipeline(self):
         if self.pipeline_validated:
             LOG.info(_LI("Reconfiguring polling tasks."))
 
             # stop existing pollsters and leave partitioning groups
-            self.stop_pollsters()
+            self.stop_pollsters_tasks()
             for group in self.groups:
                 self.partition_coordinator.leave_group(group)
 
             # re-create partitioning groups according to pipeline
             # and configure polling tasks with latest pipeline conf
             self.join_partitioning_groups()
-            self.pollster_timers = self.configure_polling_tasks()
+            self.start_polling_tasks()
