@@ -16,38 +16,21 @@
 
 """Access Control Lists (ACL's) control access the API server."""
 
-from oslo_config import cfg
-from oslo_policy import policy
 import pecan
 
-_ENFORCER = None
-
-CONF = cfg.CONF
-
-
-def reset():
-    global _ENFORCER
-    if _ENFORCER:
-        _ENFORCER.clear()
-        _ENFORCER = None
-
 
 def _has_rule(name):
-    return name in _ENFORCER.rules.keys()
+    return name in pecan.request.enforcer.rules.keys()
 
 
 def enforce(policy_name, request):
-    """Return the user and project the request should be limited to.
+    """Checks authorization of a rule against the request.
 
     :param request: HTTP request
     :param policy_name: the policy name to validate authz against.
 
 
     """
-    global _ENFORCER
-    if not _ENFORCER:
-        _ENFORCER = policy.Enforcer(CONF)
-        _ENFORCER.load_rules()
 
     rule_method = "telemetry:" + policy_name
     headers = request.headers
@@ -60,7 +43,7 @@ def enforce(policy_name, request):
     # maintain backward compat with Juno and previous by allowing the action if
     # there is no rule defined for it
     if ((_has_rule('default') or _has_rule(rule_method)) and
-            not _ENFORCER.enforce(rule_method, {}, policy_dict)):
+            not pecan.request.enforcer.enforce(rule_method, {}, policy_dict)):
         pecan.core.abort(status_code=403, detail='RBAC Authorization Failed')
 
 
@@ -75,10 +58,6 @@ def get_limited_to(headers):
     one of these.
 
     """
-    global _ENFORCER
-    if not _ENFORCER:
-        _ENFORCER = policy.Enforcer(CONF)
-        _ENFORCER.load_rules()
 
     policy_dict = dict()
     policy_dict['roles'] = headers.get('X-Roles', "").split(",")
@@ -89,9 +68,9 @@ def get_limited_to(headers):
     # rule if the segregation rule (added in Kilo) is not defined
     rule_name = 'segregation' if _has_rule(
         'segregation') else 'context_is_admin'
-    if not _ENFORCER.enforce(rule_name,
-                             {},
-                             policy_dict):
+    if not pecan.request.enforcer.enforce(rule_name,
+                                          {},
+                                          policy_dict):
         return headers.get('X-User-Id'), headers.get('X-Project-Id')
 
     return None, None
