@@ -14,9 +14,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import cotyledon
+from cotyledon import oslo_config_glue
 from oslo_config import cfg
 from oslo_log import log
-from oslo_service import service as os_service
 
 from ceilometer.agent import manager
 from ceilometer.i18n import _LW
@@ -24,8 +25,6 @@ from ceilometer import service
 
 LOG = log.getLogger(__name__)
 
-CONF = cfg.CONF
-
 
 class MultiChoicesOpt(cfg.Opt):
     def __init__(self, name, choices=None, **kwargs):
@@ -75,10 +74,19 @@ CLI_OPTS = [
                          'used while polling'),
 ]
 
-CONF.register_cli_opts(CLI_OPTS)
+
+def create_polling_service(worker_id, conf):
+    return manager.AgentManager(worker_id,
+                                conf,
+                                conf.polling_namespaces,
+                                conf.pollster_list)
 
 
 def main():
-    service.prepare_service()
-    os_service.launch(CONF, manager.AgentManager(CONF.polling_namespaces,
-                                                 CONF.pollster_list)).wait()
+    conf = cfg.ConfigOpts()
+    conf.register_cli_opts(CLI_OPTS)
+    service.prepare_service(conf=conf)
+    sm = cotyledon.ServiceManager()
+    sm.add(create_polling_service, args=(conf,))
+    oslo_config_glue.setup(sm, conf)
+    sm.run()
