@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import datetime
-
 from keystoneauth1 import exceptions
 from oslo_config import cfg
 from oslo_log import log
@@ -33,14 +31,13 @@ SERVICE_OPTS = [
                help='Kwapi service type.'),
 ]
 
-cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
-
 
 class KwapiClient(object):
     """Kwapi API client."""
 
-    def __init__(self, url, token=None):
+    def __init__(self, conf, url, token=None):
         """Initializes client."""
+        self.conf = conf
         self.url = url
         self.token = token
 
@@ -50,7 +47,7 @@ class KwapiClient(object):
         headers = {}
         if self.token is not None:
             headers = {'X-Auth-Token': self.token}
-        timeout = cfg.CONF.http_timeout
+        timeout = self.conf.http_timeout
         request = requests.get(probes_url, headers=headers, timeout=timeout)
         message = request.json()
         probes = message['probes']
@@ -65,12 +62,12 @@ class _Base(plugin_base.PollsterBase):
 
     @property
     def default_discovery(self):
-        return 'endpoint:%s' % cfg.CONF.service_types.kwapi
+        return 'endpoint:%s' % self.conf.service_types.kwapi
 
-    @staticmethod
-    def get_kwapi_client(ksclient, endpoint):
+    def get_kwapi_client(self, ksclient, endpoint):
         """Returns a KwapiClient configured with the proper url and token."""
-        return KwapiClient(endpoint, keystone_client.get_auth_token(ksclient))
+        return KwapiClient(self.conf, endpoint,
+                           keystone_client.get_auth_token(ksclient))
 
     CACHE_KEY_PROBE = 'kwapi.probes'
 
@@ -104,8 +101,6 @@ class EnergyPollster(_Base):
                     user_id=None,
                     project_id=None,
                     resource_id=probe['id'],
-                    timestamp=datetime.datetime.fromtimestamp(
-                        probe['timestamp']).isoformat(),
                     resource_metadata={}
                 )
 
@@ -124,7 +119,5 @@ class PowerPollster(_Base):
                     user_id=None,
                     project_id=None,
                     resource_id=probe['id'],
-                    timestamp=datetime.datetime.fromtimestamp(
-                        probe['timestamp']).isoformat(),
                     resource_metadata={}
                 )
