@@ -13,8 +13,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-import oslo_context.context
 import oslo_messaging
 from oslo_messaging import serializer as oslo_serializer
 
@@ -26,14 +24,14 @@ def setup():
     oslo_messaging.set_transport_defaults('ceilometer')
 
 
-def get_transport(url=None, optional=False, cache=True):
+def get_transport(conf, url=None, optional=False, cache=True):
     """Initialise the oslo_messaging layer."""
     global TRANSPORTS, DEFAULT_URL
     cache_key = url or DEFAULT_URL
     transport = TRANSPORTS.get(cache_key)
     if not transport or not cache:
         try:
-            transport = oslo_messaging.get_transport(cfg.CONF, url)
+            transport = oslo_messaging.get_transport(conf, url)
         except (oslo_messaging.InvalidTransportURL,
                 oslo_messaging.DriverLoadFailure):
             if not optional or url:
@@ -56,30 +54,7 @@ def cleanup():
         del TRANSPORTS[url]
 
 
-class RequestContextSerializer(oslo_messaging.Serializer):
-
-    def __init__(self, base):
-        self._base = base
-
-    def serialize_entity(self, context, entity):
-        if not self._base:
-            return entity
-        return self._base.serialize_entity(context, entity)
-
-    def deserialize_entity(self, context, entity):
-        if not self._base:
-            return entity
-        return self._base.deserialize_entity(context, entity)
-
-    def serialize_context(self, context):
-        return context.to_dict()
-
-    def deserialize_context(self, context):
-        return oslo_context.context.RequestContext.from_dict(context)
-
-
-_SERIALIZER = RequestContextSerializer(
-    oslo_serializer.JsonPayloadSerializer())
+_SERIALIZER = oslo_serializer.JsonPayloadSerializer()
 
 
 def get_batch_notification_listener(transport, targets, endpoints,
