@@ -15,17 +15,16 @@ import itertools
 import pkg_resources
 import six
 
-from debtcollector import moves
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
+from oslo_utils import fnmatch
 from stevedore import extension
 
 from ceilometer.agent import plugin_base
 from ceilometer import declarative
 from ceilometer.i18n import _LE, _LW
-from ceilometer import sample
-from ceilometer import utils
+from ceilometer import sample as sample_util
 
 OPTS = [
     cfg.StrOpt('meter_definitions_cfg_file',
@@ -34,20 +33,9 @@ OPTS = [
                ),
 ]
 
-cfg.CONF.register_opts(OPTS, group='meter')
-cfg.CONF.import_opt('disable_non_metric_meters', 'ceilometer.notification',
-                    group='notification')
-
 LOG = log.getLogger(__name__)
 
 
-MeterDefinitionException = moves.moved_class(declarative.DefinitionException,
-                                             'MeterDefinitionException',
-                                             __name__,
-                                             version=6.0,
-                                             removal_version="?")
-
-
 class MeterDefinition(object):
 
     SAMPLE_ATTRIBUTES = ["name", "type", "volume", "unit", "timestamp",
@@ -56,12 +44,13 @@ class MeterDefinition(object):
     REQUIRED_FIELDS = ['name', 'type', 'event_type', 'unit', 'volume',
                        'resource_id']
 
-    def __init__(self, definition_cfg, plugin_manager):
+    def __init__(self, definition_cfg, conf, plugin_manager):
+        self.conf = conf
         self.cfg = definition_cfg
         missing = [field for field in self.REQUIRED_FIELDS
                    if not self.cfg.get(field)]
         if missing:
-            raise declarative.DefinitionException(
+            raise declarative.MeterDefinitionException(
                 _LE("Required fields %s not specified") % missing, self.cfg)
 
         self._event_type = self.cfg.get('event_type')
@@ -69,8 +58,8 @@ class MeterDefinition(object):
             self._event_type = [self._event_type]
 
         if ('type' not in self.cfg.get('lookup', []) and
-                self.cfg['type'] not in sample.TYPES):
-            raise declarative.DefinitionException(
+                self.cfg['type'] not in sample_util.TYPES):
+            raise declarative.MeterDefinitionException(
                 _LE("Invalid type %s specified") % self.cfg['type'], self.cfg)
 
         self._fallback_user_id = declarative.Definition(
@@ -79,6 +68,7 @@ class MeterDefinition(object):
             'project_id', "_context_tenant_id|_context_tenant", plugin_manager)
         self._attributes = {}
         self._metadata_attributes = {}
+        self._user_meta = None
 
         for name in self.SAMPLE_ATTRIBUTES:
             attr_cfg = self.cfg.get(name)
@@ -89,6 +79,10 @@ class MeterDefinition(object):
         for name in metadata:
             self._metadata_attributes[name] = declarative.Definition(
                 name, metadata[name], plugin_manager)
+        user_meta = self.cfg.get('user_metadata')
+        if user_meta:
+            self._user_meta = declarative.Definition(None, user_meta,
+                                                     plugin_manager)
 
         # List of fields we expected when multiple meter are in the payload
         self.lookup = self.cfg.get('lookup')
@@ -97,7 +91,7 @@ class MeterDefinition(object):
 
     def match_type(self, meter_name):
         for t in self._event_type:
-            if utils.match(meter_name, t):
+            if fnmatch.fnmatch(meter_name, t):
                 return True
 
     def to_samples(self, message, all_values=False):
@@ -114,6 +108,12 @@ class MeterDefinition(object):
             if value:
                 sample['metadata'][name] = value
 
+        if self._user_meta:
+            meta = self._user_meta.parse(message)
+            if meta:
+                sample_util.add_reserved_user_metadata(
+                    self.conf, meta, sample['metadata'])
+
         # NOTE(sileht): We expect multiple samples in the payload
         # so put each attribute into a list
         if self.lookup:
@@ -125,7 +125,7 @@ class MeterDefinition(object):
             if parser is not None:
                 value = parser.parse(message, bool(self.lookup))
                 # NOTE(sileht): If we expect multiple samples
-                # some attributes and overriden even we doesn't get any
+                # some attributes are overridden even we don't get any
                 # result. Also note in this case value is always a list
                 if ((not self.lookup and value is not None) or
                         (self.lookup and ((name in self.lookup + ["name"])
@@ -174,12 +174,12 @@ class ProcessMeterNotifications(plugin_base.NotificationBase):
         super(ProcessMeterNotifications, self).__init__(manager)
         self.definitions = self._load_definitions()
 
-    @staticmethod
-    def _load_definitions():
+    def _load_definitions(self):
         plugin_manager = extension.ExtensionManager(
             namespace='ceilometer.event.trait_plugin')
         meters_cfg = declarative.load_definitions(
-            {}, cfg.CONF.meter.meter_definitions_cfg_file,
+            self.manager.conf, {},
+            self.manager.conf.meter.meter_definitions_cfg_file,
             pkg_resources.resource_filename(__name__, "data/meters.yaml"))
 
         definitions = {}
@@ -189,16 +189,14 @@ class ProcessMeterNotifications(plugin_base.NotificationBase):
                 LOG.warning(_LW("Skipping duplicate meter definition %s")
                             % meter_cfg)
                 continue
-            if (meter_cfg.get('volume') != 1
-                    or not cfg.CONF.notification.disable_non_metric_meters):
-                try:
-                    md = MeterDefinition(meter_cfg, plugin_manager)
-                except declarative.DefinitionException as me:
-                    errmsg = (_LE("Error loading meter definition : %(err)s")
-                              % dict(err=six.text_type(me)))
-                    LOG.error(errmsg)
-                else:
-                    definitions[meter_cfg['name']] = md
+            try:
+                md = MeterDefinition(meter_cfg, self.manager.conf,
+                                     plugin_manager)
+            except declarative.DefinitionException as e:
+                errmsg = _LE("Error loading meter definition: %s")
+                LOG.error(errmsg, six.text_type(e))
+            else:
+                definitions[meter_cfg['name']] = md
         return definitions.values()
 
     def get_targets(self, conf):
@@ -220,7 +218,6 @@ class ProcessMeterNotifications(plugin_base.NotificationBase):
             conf.trove_control_exchange,
             conf.zaqar_control_exchange,
             conf.swift_control_exchange,
-            conf.magnetodb_control_exchange,
             conf.ceilometer_control_exchange,
             conf.magnum_control_exchange,
             conf.dns_control_exchange,
@@ -237,4 +234,4 @@ class ProcessMeterNotifications(plugin_base.NotificationBase):
         for d in self.definitions:
             if d.match_type(notification_body['event_type']):
                 for s in d.to_samples(notification_body):
-                    yield sample.Sample.from_notification(**s)
+                    yield sample_util.Sample.from_notification(**s)
