@@ -31,9 +31,6 @@ SERVICE_OPTS = [
                help='Neutron load balancer version.')
 ]
 
-cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
-cfg.CONF.import_group('service_credentials', 'ceilometer.keystone_client')
-
 LOG = log.getLogger(__name__)
 
 
@@ -59,16 +56,16 @@ def logged(func):
 class Client(object):
     """A client which gets information via python-neutronclient."""
 
-    def __init__(self):
-        conf = cfg.CONF.service_credentials
+    def __init__(self, conf):
+        creds = conf.service_credentials
         params = {
-            'session': keystone_client.get_session(),
-            'endpoint_type': conf.interface,
-            'region_name': conf.region_name,
-            'service_type': cfg.CONF.service_types.neutron,
+            'session': keystone_client.get_session(conf),
+            'endpoint_type': creds.interface,
+            'region_name': creds.region_name,
+            'service_type': conf.service_types.neutron,
         }
         self.client = clientv20.Client(**params)
-        self.lb_version = cfg.CONF.service_types.neutron_lbaas_version
+        self.lb_version = conf.service_types.neutron_lbaas_version
 
     @logged
     def port_get_all(self):
@@ -272,7 +269,7 @@ class Client(object):
         pool_id].
         :returns: The status dictionary of the member
         resource. The key is the ID of the member. The value is
-        the operating statuse of the member resource.
+        the operating status of the member resource.
         """
         # FIXME(liamji) the following meters are experimental and
         # may generate a large load against neutron api. The future
@@ -318,7 +315,7 @@ class Client(object):
         :param loadbalancer_id: The ID of the Load Balancer.
         :returns: The status dictionary of the listener
         resource. The key is the ID of the listener resource. The
-        value is the operating statuse of the listener resource.
+        value is the operating status of the listener resource.
         """
         # FIXME(liamji) the following meters are experimental and
         # may generate a large load against neutron api. The future
@@ -356,7 +353,7 @@ class Client(object):
         :param parent_id: The parent ID of the pool resource.
         :returns: The status dictionary of the pool resource.
         The key is the ID of the pool resource. The value is
-        the operating statuse of the pool resource.
+        the operating status of the pool resource.
         """
         # FIXME(liamji) the following meters are experimental and
         # may generate a large load against neutron api. The future
