@@ -12,9 +12,10 @@
 # under the License.
 
 import functools
-import logging
 
+import glanceclient
 import novaclient
+from novaclient import api_versions
 from novaclient import client as nova_client
 from oslo_config import cfg
 from oslo_log import log
@@ -24,7 +25,7 @@ from ceilometer import keystone_client
 OPTS = [
     cfg.BoolOpt('nova_http_log_debug',
                 default=False,
-                # Added in Mikita
+                # Added in Mitaka
                 deprecated_for_removal=True,
                 help=('Allow novaclient\'s debug log output. '
                       '(Use default_log_levels instead)')),
@@ -36,11 +37,6 @@ SERVICE_OPTS = [
                help='Nova service type.'),
 ]
 
-cfg.CONF.register_opts(OPTS)
-cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
-cfg.CONF.import_opt('http_timeout', 'ceilometer.service')
-cfg.CONF.import_group('service_credentials', 'ceilometer.keystone_client')
-
 LOG = log.getLogger(__name__)
 
 
@@ -60,29 +56,33 @@ def logged(func):
 class Client(object):
     """A client which gets information via python-novaclient."""
 
-    def __init__(self, endpoint_override=None, auth=None):
+    def __init__(self, conf):
         """Initialize a nova client object."""
-        conf = cfg.CONF.service_credentials
+        creds = conf.service_credentials
 
         logger = None
-        if cfg.CONF.nova_http_log_debug:
-            logger = logging.getLogger("novaclient-debug")
-            logger.setLevel(log.DEBUG)
+        if conf.nova_http_log_debug:
+            logger = log.getLogger("novaclient-debug")
+            logger.logger.setLevel(log.DEBUG)
+        ks_session = keystone_client.get_session(conf)
 
         self.nova_client = nova_client.Client(
-            version=2,
-            session=keystone_client.get_session(),
+            version=api_versions.APIVersion('2.1'),
+            session=ks_session,
 
             # nova adapter options
-            region_name=conf.region_name,
-            interface=conf.interface,
-            service_type=cfg.CONF.service_types.nova,
-
-            # keystone adapter options
-            endpoint_override=endpoint_override,
-            auth=auth,
+            region_name=creds.region_name,
+            endpoint_type=creds.interface,
+            service_type=conf.service_types.nova,
             logger=logger)
 
+        self.glance_client = glanceclient.Client(
+            version='2',
+            session=ks_session,
+            region_name=creds.region_name,
+            interface=creds.interface,
+            service_type=conf.service_types.glance)
+
     def _with_flavor_and_image(self, instances):
         flavor_cache = {}
         image_cache = {}
@@ -126,8 +126,8 @@ class Client(object):
             image = cache.get(iid)
         else:
             try:
-                image = self.nova_client.images.get(iid)
-            except novaclient.exceptions.NotFound:
+                image = self.glance_client.images.get(iid)
+            except glanceclient.exc.HTTPNotFound:
                 image = None
             cache[iid] = image
 
@@ -169,8 +169,3 @@ class Client(object):
         return self.nova_client.servers.list(
             detailed=True,
             search_opts=search_opts)
-
-    @logged
-    def floating_ip_get_all(self):
-        """Returns all floating ips."""
-        return self.nova_client.floating_ips.list()
