@@ -54,10 +54,6 @@ NOTIFIER_OPTS = [
                )
 ]
 
-cfg.CONF.register_opts(NOTIFIER_OPTS,
-                       group="publisher_notifier")
-cfg.CONF.import_opt('host', 'ceilometer.service')
-
 
 class DeliveryFailure(Exception):
     def __init__(self, message=None, cause=None):
@@ -72,9 +68,10 @@ def raise_delivery_failure(exc):
 
 
 @six.add_metaclass(abc.ABCMeta)
-class MessagingPublisher(publisher.PublisherBase):
+class MessagingPublisher(publisher.ConfigPublisherBase):
 
-    def __init__(self, parsed_url):
+    def __init__(self, conf, parsed_url):
+        super(MessagingPublisher, self).__init__(conf, parsed_url)
         options = urlparse.parse_qs(parsed_url.query)
         # the value of options is a list of url param values
         # only take care of the latest one if the option
@@ -90,29 +87,28 @@ class MessagingPublisher(publisher.PublisherBase):
         self.local_queue = []
 
         if self.policy in ['default', 'queue', 'drop']:
-            LOG.info(_LI('Publishing policy set to %s') % self.policy)
+            LOG.info(_LI('Publishing policy set to %s'), self.policy)
         else:
             LOG.warning(_('Publishing policy is unknown (%s) force to '
-                          'default') % self.policy)
+                          'default'), self.policy)
             self.policy = 'default'
 
         self.retry = 1 if self.policy in ['queue', 'drop'] else None
 
-    def publish_samples(self, context, samples):
+    def publish_samples(self, samples):
         """Publish samples on RPC.
 
-        :param context: Execution context from the service or RPC call.
         :param samples: Samples from pipeline after transformation.
 
         """
 
         meters = [
             utils.meter_message_from_counter(
-                sample, cfg.CONF.publisher.telemetry_secret)
+                sample, self.conf.publisher.telemetry_secret)
             for sample in samples
         ]
-        topic = cfg.CONF.publisher_notifier.metering_topic
-        self.local_queue.append((context, topic, meters))
+        topic = self.conf.publisher_notifier.metering_topic
+        self.local_queue.append((topic, meters))
 
         if self.per_meter_topic:
             for meter_name, meter_list in itertools.groupby(
@@ -122,7 +118,7 @@ class MessagingPublisher(publisher.PublisherBase):
                 topic_name = topic + '.' + meter_name
                 LOG.debug('Publishing %(m)d samples on %(n)s',
                           {'m': len(meter_list), 'n': topic_name})
-                self.local_queue.append((context, topic_name, meter_list))
+                self.local_queue.append((topic_name, meter_list))
 
         self.flush()
 
@@ -150,11 +146,11 @@ class MessagingPublisher(publisher.PublisherBase):
     def _process_queue(self, queue, policy):
         current_retry = 0
         while queue:
-            context, topic, data = queue[0]
+            topic, data = queue[0]
             try:
-                self._send(context, topic, data)
+                self._send(topic, data)
             except DeliveryFailure:
-                data = sum([len(m) for __, __, m in queue])
+                data = sum([len(m) for __, m in queue])
                 if policy == 'queue':
                     LOG.warning(_("Failed to publish %d datapoints, queue "
                                   "them"), data)
@@ -172,52 +168,58 @@ class MessagingPublisher(publisher.PublisherBase):
                 queue.pop(0)
         return []
 
-    def publish_events(self, context, events):
+    def publish_events(self, events):
         """Send an event message for publishing
 
-        :param context: Execution context from the service or RPC call
         :param events: events from pipeline after transformation
         """
         ev_list = [utils.message_from_event(
-            event, cfg.CONF.publisher.telemetry_secret) for event in events]
+            event, self.conf.publisher.telemetry_secret) for event in events]
 
-        topic = cfg.CONF.publisher_notifier.event_topic
-        self.local_queue.append((context, topic, ev_list))
+        topic = self.conf.publisher_notifier.event_topic
+        self.local_queue.append((topic, ev_list))
         self.flush()
 
     @abc.abstractmethod
-    def _send(self, context, topic, meters):
+    def _send(self, topic, meters):
         """Send the meters to the messaging topic."""
 
 
 class NotifierPublisher(MessagingPublisher):
-    def __init__(self, parsed_url, default_topic):
-        super(NotifierPublisher, self).__init__(parsed_url)
+    def __init__(self, conf, parsed_url, default_topic):
+        super(NotifierPublisher, self).__init__(conf, parsed_url)
         options = urlparse.parse_qs(parsed_url.query)
-        topic = options.get('topic', [default_topic])[-1]
+        topic = options.pop('topic', [default_topic])
+        driver = options.pop('driver', ['rabbit'])[0]
+        url = None
+        if parsed_url.netloc != '':
+            url = urlparse.urlunsplit([driver, parsed_url.netloc,
+                                       parsed_url.path,
+                                       urlparse.urlencode(options, True),
+                                       parsed_url.fragment])
         self.notifier = oslo_messaging.Notifier(
-            messaging.get_transport(),
-            driver=cfg.CONF.publisher_notifier.telemetry_driver,
-            publisher_id='telemetry.publisher.%s' % cfg.CONF.host,
-            topic=topic,
+            messaging.get_transport(self.conf, url),
+            driver=self.conf.publisher_notifier.telemetry_driver,
+            publisher_id='telemetry.publisher.%s' % self.conf.host,
+            topics=topic,
             retry=self.retry
         )
 
-    def _send(self, context, event_type, data):
+    def _send(self, event_type, data):
         try:
-            self.notifier.sample(context.to_dict(), event_type=event_type,
+            self.notifier.sample({}, event_type=event_type,
                                  payload=data)
         except oslo_messaging.MessageDeliveryFailure as e:
             raise_delivery_failure(e)
 
 
 class SampleNotifierPublisher(NotifierPublisher):
-    def __init__(self, parsed_url):
+    def __init__(self, conf, parsed_url):
         super(SampleNotifierPublisher, self).__init__(
-            parsed_url, cfg.CONF.publisher_notifier.metering_topic)
+            conf, parsed_url, conf.publisher_notifier.metering_topic)
 
 
 class EventNotifierPublisher(NotifierPublisher):
-    def __init__(self, parsed_url):
+    def __init__(self, conf, parsed_url):
         super(EventNotifierPublisher, self).__init__(
-            parsed_url, cfg.CONF.publisher_notifier.event_topic)
+            conf, parsed_url, conf.publisher_notifier.event_topic)
