@@ -20,8 +20,10 @@ import mock
 from oslo_config import fixture as fixture_config
 import six
 
+from ceilometer import declarative
 from ceilometer.event import converter
 from ceilometer.event.storage import models
+from ceilometer import service as ceilometer_service
 from ceilometer.tests import base
 
 
@@ -112,13 +114,13 @@ class TestTraitDefinition(ConverterBase):
         self.ext1 = mock.MagicMock(name='mock_test_plugin')
         self.test_plugin_class = self.ext1.plugin
         self.test_plugin = self.test_plugin_class()
-        self.test_plugin.trait_value.return_value = 'foobar'
+        self.test_plugin.trait_values.return_value = ['foobar']
         self.ext1.reset_mock()
 
         self.ext2 = mock.MagicMock(name='mock_nothing_plugin')
         self.nothing_plugin_class = self.ext2.plugin
         self.nothing_plugin = self.nothing_plugin_class()
-        self.nothing_plugin.trait_value.return_value = None
+        self.nothing_plugin.trait_values.return_value = [None]
         self.ext2.reset_mock()
 
         self.fake_plugin_mgr = dict(test=self.ext1, nothing=self.ext2)
@@ -136,7 +138,7 @@ class TestTraitDefinition(ConverterBase):
         self.assertEqual(models.Trait.TEXT_TYPE, t.dtype)
         self.assertEqual('foobar', t.value)
         self.test_plugin_class.assert_called_once_with()
-        self.test_plugin.trait_value.assert_called_once_with([
+        self.test_plugin.trait_values.assert_called_once_with([
             ('payload.instance_id', 'id-for-instance-0001'),
             ('payload.instance_uuid', 'uuid-for-instance-0001')])
 
@@ -153,7 +155,7 @@ class TestTraitDefinition(ConverterBase):
         self.assertEqual(models.Trait.TEXT_TYPE, t.dtype)
         self.assertEqual('foobar', t.value)
         self.test_plugin_class.assert_called_once_with()
-        self.test_plugin.trait_value.assert_called_once_with([])
+        self.test_plugin.trait_values.assert_called_once_with([])
 
     def test_to_trait_with_plugin_null(self):
         cfg = dict(type='text',
@@ -163,9 +165,9 @@ class TestTraitDefinition(ConverterBase):
         tdef = converter.TraitDefinition('test_trait', cfg,
                                          self.fake_plugin_mgr)
         t = tdef.to_trait(self.n1)
-        self.assertIs(None, t)
+        self.assertIsNone(t)
         self.nothing_plugin_class.assert_called_once_with()
-        self.nothing_plugin.trait_value.assert_called_once_with([
+        self.nothing_plugin.trait_values.assert_called_once_with([
             ('payload.instance_id', 'id-for-instance-0001'),
             ('payload.instance_uuid', 'uuid-for-instance-0001')])
 
@@ -182,7 +184,7 @@ class TestTraitDefinition(ConverterBase):
         self.assertEqual(models.Trait.TEXT_TYPE, t.dtype)
         self.assertEqual('foobar', t.value)
         self.test_plugin_class.assert_called_once_with(a=1, b='foo')
-        self.test_plugin.trait_value.assert_called_once_with([
+        self.test_plugin.trait_values.assert_called_once_with([
             ('payload.instance_id', 'id-for-instance-0001'),
             ('payload.instance_uuid', 'uuid-for-instance-0001')])
 
@@ -262,21 +264,21 @@ class TestTraitDefinition(ConverterBase):
         tdef = converter.TraitDefinition('test_trait', cfg,
                                          self.fake_plugin_mgr)
         t = tdef.to_trait(self.n1)
-        self.assertIs(None, t)
+        self.assertIsNone(t)
 
     def test_to_trait_null(self):
         cfg = dict(type='text', fields='payload.instance_id2')
         tdef = converter.TraitDefinition('test_trait', cfg,
                                          self.fake_plugin_mgr)
         t = tdef.to_trait(self.n1)
-        self.assertIs(None, t)
+        self.assertIsNone(t)
 
     def test_to_trait_empty_nontext(self):
         cfg = dict(type='datetime', fields='payload.bogus_date')
         tdef = converter.TraitDefinition('test_trait', cfg,
                                          self.fake_plugin_mgr)
         t = tdef.to_trait(self.n1)
-        self.assertIs(None, t)
+        self.assertIsNone(t)
 
     def test_to_trait_multiple_null_missing(self):
         cfg = dict(type='text', fields=['payload.not_here_boss',
@@ -284,10 +286,10 @@ class TestTraitDefinition(ConverterBase):
         tdef = converter.TraitDefinition('test_trait', cfg,
                                          self.fake_plugin_mgr)
         t = tdef.to_trait(self.n1)
-        self.assertIs(None, t)
+        self.assertIsNone(t)
 
     def test_missing_fields_config(self):
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.TraitDefinition,
                           'bogus_trait',
                           dict(),
@@ -296,19 +298,20 @@ class TestTraitDefinition(ConverterBase):
     def test_string_fields_config(self):
         cfg = dict(fields='payload.test')
         t = converter.TraitDefinition('test_trait', cfg, self.fake_plugin_mgr)
-        self.assertPathsEqual(t.fields, jsonpath_rw_ext.parse('payload.test'))
+        self.assertPathsEqual(t.getter.__self__,
+                              jsonpath_rw_ext.parse('payload.test'))
 
     def test_list_fields_config(self):
         cfg = dict(fields=['payload.test', 'payload.other'])
         t = converter.TraitDefinition('test_trait', cfg, self.fake_plugin_mgr)
         self.assertPathsEqual(
-            t.fields,
+            t.getter.__self__,
             jsonpath_rw_ext.parse('(payload.test)|(payload.other)'))
 
     def test_invalid_path_config(self):
         # test invalid jsonpath...
         cfg = dict(fields='payload.bogus(')
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.TraitDefinition,
                           'bogus_trait',
                           cfg,
@@ -317,7 +320,7 @@ class TestTraitDefinition(ConverterBase):
     def test_invalid_plugin_config(self):
         # test invalid jsonpath...
         cfg = dict(fields='payload.test', plugin=dict(bogus="true"))
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.TraitDefinition,
                           'test_trait',
                           cfg,
@@ -326,7 +329,7 @@ class TestTraitDefinition(ConverterBase):
     def test_unknown_plugin(self):
         # test invalid jsonpath...
         cfg = dict(fields='payload.test', plugin=dict(name='bogus'))
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.TraitDefinition,
                           'test_trait',
                           cfg,
@@ -352,7 +355,7 @@ class TestTraitDefinition(ConverterBase):
     def test_invalid_type_config(self):
         # test invalid jsonpath...
         cfg = dict(type='bogus', fields='payload.test')
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.TraitDefinition,
                           'bogus_trait',
                           cfg,
@@ -397,7 +400,7 @@ class TestEventDefinition(ConverterBase):
     def test_to_event(self):
         dtype = models.Trait.TEXT_TYPE
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
 
         e = edef.to_event(self.test_notification1)
         self.assertEqual('test.thing', e.event_type)
@@ -413,7 +416,7 @@ class TestEventDefinition(ConverterBase):
     def test_to_event_missing_trait(self):
         dtype = models.Trait.TEXT_TYPE
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
 
         e = edef.to_event(self.test_notification2)
 
@@ -426,7 +429,7 @@ class TestEventDefinition(ConverterBase):
     def test_to_event_null_trait(self):
         dtype = models.Trait.TEXT_TYPE
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
 
         e = edef.to_event(self.test_notification3)
 
@@ -438,21 +441,23 @@ class TestEventDefinition(ConverterBase):
 
     def test_bogus_cfg_no_traits(self):
         bogus = dict(event_type='test.foo')
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.EventDefinition,
                           bogus,
-                          self.fake_plugin_mgr)
+                          self.fake_plugin_mgr,
+                          [])
 
     def test_bogus_cfg_no_type(self):
         bogus = dict(traits=self.traits_cfg)
-        self.assertRaises(converter.EventDefinitionException,
+        self.assertRaises(declarative.DefinitionException,
                           converter.EventDefinition,
                           bogus,
-                          self.fake_plugin_mgr)
+                          self.fake_plugin_mgr,
+                          [])
 
     def test_included_type_string(self):
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertEqual(1, len(edef._included_types))
         self.assertEqual('test.thing', edef._included_types[0])
         self.assertEqual(0, len(edef._excluded_types))
@@ -464,7 +469,7 @@ class TestEventDefinition(ConverterBase):
     def test_included_type_list(self):
         cfg = dict(event_type=['test.thing', 'other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertEqual(2, len(edef._included_types))
         self.assertEqual(0, len(edef._excluded_types))
         self.assertTrue(edef.included_type('test.thing'))
@@ -476,7 +481,7 @@ class TestEventDefinition(ConverterBase):
 
     def test_excluded_type_string(self):
         cfg = dict(event_type='!test.thing', traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertEqual(1, len(edef._included_types))
         self.assertEqual('*', edef._included_types[0])
         self.assertEqual('test.thing', edef._excluded_types[0])
@@ -490,7 +495,7 @@ class TestEventDefinition(ConverterBase):
     def test_excluded_type_list(self):
         cfg = dict(event_type=['!test.thing', '!other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertEqual(1, len(edef._included_types))
         self.assertEqual(2, len(edef._excluded_types))
         self.assertTrue(edef.excluded_type('test.thing'))
@@ -503,7 +508,7 @@ class TestEventDefinition(ConverterBase):
     def test_mixed_type_list(self):
         cfg = dict(event_type=['*.thing', '!test.thing', '!other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertEqual(1, len(edef._included_types))
         self.assertEqual(2, len(edef._excluded_types))
         self.assertTrue(edef.excluded_type('test.thing'))
@@ -517,32 +522,32 @@ class TestEventDefinition(ConverterBase):
     def test_catchall(self):
         cfg = dict(event_type=['*.thing', '!test.thing', '!other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertFalse(edef.is_catchall)
 
         cfg = dict(event_type=['!other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertFalse(edef.is_catchall)
 
         cfg = dict(event_type=['other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertFalse(edef.is_catchall)
 
         cfg = dict(event_type=['*', '!other.thing'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertFalse(edef.is_catchall)
 
         cfg = dict(event_type=['*'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertTrue(edef.is_catchall)
 
         cfg = dict(event_type=['*', 'foo'],
                    traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         self.assertTrue(edef.is_catchall)
 
     @mock.patch('oslo_utils.timeutils.utcnow')
@@ -569,7 +574,7 @@ class TestEventDefinition(ConverterBase):
 
     def test_default_traits(self):
         cfg = dict(event_type='test.thing', traits={})
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         default_traits = converter.EventDefinition.DEFAULT_TRAITS.keys()
         traits = set(edef.traits.keys())
         for dt in default_traits:
@@ -579,7 +584,7 @@ class TestEventDefinition(ConverterBase):
 
     def test_traits(self):
         cfg = dict(event_type='test.thing', traits=self.traits_cfg)
-        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
+        edef = converter.EventDefinition(cfg, self.fake_plugin_mgr, [])
         default_traits = converter.EventDefinition.DEFAULT_TRAITS.keys()
         traits = set(edef.traits.keys())
         for dt in default_traits:
@@ -594,7 +599,8 @@ class TestNotificationConverter(ConverterBase):
 
     def setUp(self):
         super(TestNotificationConverter, self).setUp()
-        self.CONF = self.useFixture(fixture_config.Config()).conf
+        conf = ceilometer_service.prepare_service(argv=[], config_files=[])
+        self.CONF = self.useFixture(fixture_config.Config(conf)).conf
         self.valid_event_def1 = [{
             'event_type': 'compute.instance.create.*',
             'traits': {
@@ -624,13 +630,13 @@ class TestNotificationConverter(ConverterBase):
 
     @mock.patch('oslo_utils.timeutils.utcnow')
     def test_converter_missing_keys(self, mock_utcnow):
+        self.CONF.set_override('drop_unmatched_notifications', False,
+                               group='event')
         # test a malformed notification
         now = datetime.datetime.utcnow()
         mock_utcnow.return_value = now
         c = converter.NotificationEventsConverter(
-            [],
-            self.fake_plugin_mgr,
-            add_catchall=True)
+            self.CONF, [], self.fake_plugin_mgr)
         message = {'event_type': "foo",
                    'message_id': "abc",
                    'publisher_id': "1"}
@@ -641,10 +647,10 @@ class TestNotificationConverter(ConverterBase):
         self.assertEqual(now, e.generated)
 
     def test_converter_with_catchall(self):
+        self.CONF.set_override('drop_unmatched_notifications', False,
+                               group='event')
         c = converter.NotificationEventsConverter(
-            self.valid_event_def1,
-            self.fake_plugin_mgr,
-            add_catchall=True)
+            self.CONF, self.valid_event_def1, self.fake_plugin_mgr)
         self.assertEqual(2, len(c.definitions))
         e = c.to_event(self.test_notification1)
         self.assertIsValidEvent(e, self.test_notification1)
@@ -661,10 +667,10 @@ class TestNotificationConverter(ConverterBase):
         self.assertDoesNotHaveTrait(e, 'host')
 
     def test_converter_without_catchall(self):
+        self.CONF.set_override('drop_unmatched_notifications', True,
+                               group='event')
         c = converter.NotificationEventsConverter(
-            self.valid_event_def1,
-            self.fake_plugin_mgr,
-            add_catchall=False)
+            self.CONF, self.valid_event_def1, self.fake_plugin_mgr)
         self.assertEqual(1, len(c.definitions))
         e = c.to_event(self.test_notification1)
         self.assertIsValidEvent(e, self.test_notification1)
@@ -677,10 +683,10 @@ class TestNotificationConverter(ConverterBase):
         self.assertIsNotValidEvent(e, self.test_notification2)
 
     def test_converter_empty_cfg_with_catchall(self):
+        self.CONF.set_override('drop_unmatched_notifications', False,
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [],
-            self.fake_plugin_mgr,
-            add_catchall=True)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertEqual(1, len(c.definitions))
         e = c.to_event(self.test_notification1)
         self.assertIsValidEvent(e, self.test_notification1)
@@ -693,10 +699,10 @@ class TestNotificationConverter(ConverterBase):
         self.assertHasDefaultTraits(e)
 
     def test_converter_empty_cfg_without_catchall(self):
+        self.CONF.set_override('drop_unmatched_notifications', True,
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [],
-            self.fake_plugin_mgr,
-            add_catchall=False)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertEqual(0, len(c.definitions))
         e = c.to_event(self.test_notification1)
         self.assertIsNotValidEvent(e, self.test_notification1)
@@ -711,60 +717,66 @@ class TestNotificationConverter(ConverterBase):
         return convert.to_event(message)
 
     def test_store_raw_all(self):
-        self.CONF.event.store_raw = ['info', 'error']
+        self.CONF.set_override('store_raw', ['info', 'error'],
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertTrue(self._convert_message(c, 'info').raw)
         self.assertTrue(self._convert_message(c, 'error').raw)
 
     def test_store_raw_info_only(self):
-        self.CONF.event.store_raw = ['info']
+        self.CONF.set_override('store_raw', ['info'],
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertTrue(self._convert_message(c, 'info').raw)
         self.assertFalse(self._convert_message(c, 'error').raw)
 
     def test_store_raw_error_only(self):
-        self.CONF.event.store_raw = ['error']
+        self.CONF.set_override('store_raw', ['error'],
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertFalse(self._convert_message(c, 'info').raw)
         self.assertTrue(self._convert_message(c, 'error').raw)
 
     def test_store_raw_skip_all(self):
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertFalse(self._convert_message(c, 'info').raw)
         self.assertFalse(self._convert_message(c, 'error').raw)
 
     def test_store_raw_info_only_no_case(self):
-        self.CONF.event.store_raw = ['INFO']
+        self.CONF.set_override('store_raw', ['INFO'],
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertTrue(self._convert_message(c, 'info').raw)
         self.assertFalse(self._convert_message(c, 'error').raw)
 
     def test_store_raw_bad_skip_all(self):
-        self.CONF.event.store_raw = ['unknown']
+        self.CONF.set_override('store_raw', ['unknown'],
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertFalse(self._convert_message(c, 'info').raw)
         self.assertFalse(self._convert_message(c, 'error').raw)
 
     def test_store_raw_bad_and_good(self):
-        self.CONF.event.store_raw = ['info', 'unknown']
+        self.CONF.set_override('store_raw', ['info', 'unknown'],
+                               group='event')
         c = converter.NotificationEventsConverter(
-            [], self.fake_plugin_mgr)
+            self.CONF, [], self.fake_plugin_mgr)
         self.assertTrue(self._convert_message(c, 'info').raw)
         self.assertFalse(self._convert_message(c, 'error').raw)
 
-    @mock.patch('ceilometer.event.converter.get_config_file',
-                mock.Mock(return_value=None))
     def test_setup_events_default_config(self):
+        self.CONF.set_override('definitions_cfg_file',
+                               '/not/existing/file', group='event')
         self.CONF.set_override('drop_unmatched_notifications',
                                False, group='event')
 
-        c = converter.setup_events(self.fake_plugin_mgr)
+        c = converter.setup_events(self.CONF, self.fake_plugin_mgr)
         self.assertIsInstance(c, converter.NotificationEventsConverter)
         self.assertEqual(1, len(c.definitions))
         self.assertTrue(c.definitions[0].is_catchall)
@@ -772,6 +784,6 @@ class TestNotificationConverter(ConverterBase):
         self.CONF.set_override('drop_unmatched_notifications',
                                True, group='event')
 
-        c = converter.setup_events(self.fake_plugin_mgr)
+        c = converter.setup_events(self.CONF, self.fake_plugin_mgr)
         self.assertIsInstance(c, converter.NotificationEventsConverter)
         self.assertEqual(0, len(c.definitions))
