@@ -16,6 +16,7 @@ import collections
 
 from keystoneauth1 import exceptions
 import mock
+from oslo_config import fixture as fixture_config
 from oslotest import base
 from oslotest import mockpatch
 from swiftclient import client as swift_client
@@ -63,8 +64,8 @@ ASSIGNED_TENANTS = [Tenant('tenant-000'), Tenant('tenant-001')]
 
 class TestManager(manager.AgentManager):
 
-    def __init__(self):
-        super(TestManager, self).__init__()
+    def __init__(self, worker_id, conf):
+        super(TestManager, self).__init__(worker_id, conf)
         self._keystone = mock.MagicMock()
         self._keystone_last_exception = None
         self._service_catalog = (self._keystone.session.auth.
@@ -104,8 +105,9 @@ class TestSwiftPollster(testscenarios.testcase.WithScenarios,
     @mock.patch('ceilometer.pipeline.setup_pipeline', mock.MagicMock())
     def setUp(self):
         super(TestSwiftPollster, self).setUp()
-        self.pollster = self.factory()
-        self.manager = TestManager()
+        self.CONF = self.useFixture(fixture_config.Config()).conf
+        self.pollster = self.factory(self.CONF)
+        self.manager = TestManager(0, self.CONF)
 
         if self.pollster.CACHE_KEY_METHOD == 'swift.head_account':
             self.ACCOUNTS = HEAD_ACCOUNTS
@@ -143,20 +145,25 @@ class TestSwiftPollster(testscenarios.testcase.WithScenarios,
         self.assertEqual([self.ACCOUNTS[0]], data)
 
     def test_neaten_url(self):
+        reseller_prefix = self.CONF.reseller_prefix
         test_endpoints = ['http://127.0.0.1:8080',
                           'http://127.0.0.1:8080/swift']
         test_tenant_id = 'a7fd1695fa154486a647e44aa99a1b9b'
         for test_endpoint in test_endpoints:
             standard_url = test_endpoint + '/v1/AUTH_' + test_tenant_id
 
-            url = swift._Base._neaten_url(test_endpoint, test_tenant_id)
+            url = swift._Base._neaten_url(test_endpoint, test_tenant_id,
+                                          reseller_prefix)
             self.assertEqual(standard_url, url)
-            url = swift._Base._neaten_url(test_endpoint + '/', test_tenant_id)
+            url = swift._Base._neaten_url(test_endpoint + '/', test_tenant_id,
+                                          reseller_prefix)
             self.assertEqual(standard_url, url)
             url = swift._Base._neaten_url(test_endpoint + '/v1',
-                                          test_tenant_id)
+                                          test_tenant_id,
+                                          reseller_prefix)
             self.assertEqual(standard_url, url)
-            url = swift._Base._neaten_url(standard_url, test_tenant_id)
+            url = swift._Base._neaten_url(standard_url, test_tenant_id,
+                                          reseller_prefix)
             self.assertEqual(standard_url, url)
 
     def test_metering(self):
@@ -186,9 +193,10 @@ class TestSwiftPollster(testscenarios.testcase.WithScenarios,
                     return_value=endpoint):
                 list(self.pollster.get_samples(self.manager, {},
                                                ASSIGNED_TENANTS))
-        expected = [mock.call(self.pollster._neaten_url(endpoint, t.id),
-                              self.manager._auth_token)
-                    for t in ASSIGNED_TENANTS]
+        expected = [mock.call(self.pollster._neaten_url(
+            endpoint, t.id, self.CONF.reseller_prefix),
+            self.manager._auth_token)
+            for t in ASSIGNED_TENANTS]
         self.assertEqual(expected, mock_method.call_args_list)
 
     def test_get_endpoint_only_once(self):
